@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -344,6 +344,15 @@ void        cut_assert_not_equal_double_helper
                                             const char     *expression_expected,
                                             const char     *expression_error,
                                             const char     *expression_actual);
+void        cut_assert_equal_char_helper   (char            expected,
+                                            char            actual,
+                                            const char     *expression_expected,
+                                            const char     *expression_actual);
+void        cut_assert_not_equal_char_helper
+                                           (char            expected,
+                                            char            actual,
+                                            const char     *expression_expected,
+                                            const char     *expression_actual);
 void        cut_assert_equal_string_helper (const char     *expected,
                                             const char     *actual,
                                             const char     *expression_expected,
@@ -443,9 +452,15 @@ void        cut_assert_equal_fixture_data_string_helper
                                      const char     *expression_expected,
                                      const void     *path,
                                      ...) CUT_GNUC_NULL_TERMINATED;
+#ifndef CUT_DISABLE_SOCKET_SUPPORT
+void        cut_assert_equal_sockaddr_helper
+                                    (const struct sockaddr *expected,
+                                     const struct sockaddr *actual,
+                                     const char     *expression_expected,
+                                     const char     *expression_actual);
+#endif
 void        cut_error_errno_helper  (void);
 
-
 #ifdef __cplusplus
 }
 #endif
