@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2007-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -427,6 +427,7 @@ extern "C" {
  * cut_assert_not_equal_int_least64:
  * @expected: an expected integer value.
  * @actual: an actual integer value.
+ * @...: optional message. See cut_message() for details.
  *
  * Passes if @expected != @actual.
  *
@@ -965,6 +966,7 @@ extern "C" {
  * cut_assert_equal_uint_fast8:
  * @expected: an expected unsigned integer value.
  * @actual: an actual unsigned integer value.
+ * @...: optional message. See cut_message() for details.
  *
  * Passes if @expected == @actual.
  *
@@ -1327,6 +1329,58 @@ extern "C" {
         cut_assert_not_equal_double(expected, error, actual));          \
 } while (0)
 
+/**
+ * cut_assert_equal_char:
+ * @expected: an expected char value.
+ * @actual: an actual char value.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @expected ==  @actual.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_equal_char('a', 'a'); -> Pass
+ * cut_assert_equal_char('a', 'b'); -> Fail
+ * ]|
+ *
+ * Since: 1.1.3
+ */
+#define cut_assert_equal_char(expected, actual, ...) do                 \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_equal_char_helper(expected, actual,              \
+                                         #expected, #actual),           \
+            __VA_ARGS__),                                               \
+        cut_assert_equal_char(expected, actual, __VA_ARGS__));          \
+} while (0)
+
+/**
+ * cut_assert_not_equal_char:
+ * @expected: an expected char value.
+ * @actual: an actual char value.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @expected != @actual.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_not_equal_char('a', 'b'); -> Pass
+ * cut_assert_not_equal_char('a', 'a'); -> Fail
+ * ]|
+ *
+ * Since: 1.1.3
+ */
+#define cut_assert_not_equal_char(expected, actual, ...) do             \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_not_equal_char_helper(expected, actual,          \
+                                             #expected, #actual),       \
+            __VA_ARGS__),                                               \
+        cut_assert_not_equal_char(expected, actual));                   \
+} while (0)
+
 /**
  * cut_assert_equal_string:
  * @expected: an expected string value.
@@ -1366,11 +1420,11 @@ extern "C" {
  *
  * e.g.:
  * |[
- * cut_assert_equal_string("abc", "ABC"); -> Pass
- * cut_assert_equal_string("abc", NULL);  -> Pass
- * cut_assert_equal_string(NULL, "abc");  -> Pass
- * cut_assert_equal_string("abc", "abc"); -> Fail
- * cut_assert_equal_string(NULL, NULL);   -> Fail
+ * cut_assert_not_equal_string("abc", NULL);  -> Pass
+ * cut_assert_not_equal_string(NULL, "abc");  -> Pass
+ * cut_assert_not_equal_string("abc", "ABC"); -> Pass
+ * cut_assert_not_equal_string("abc", "abc"); -> Fail
+ * cut_assert_not_equal_string(NULL, NULL);   -> Fail
  * ]|
  *
  * Since: 1.0.7
@@ -1944,6 +1998,34 @@ extern "C" {
         cut_assert_equal_fixture_data_string(expected, path,            \
                                              __VA_ARGS__))
 
+/**
+ * cut_assert_equal_sockaddr:
+ * @expected: an expected socket address.
+ * @actual: an actual socket address.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @expected == @actual.
+ *
+ * This assertion can be disabled by defining CUT_DISABLE_SOCKET_SUPPORT.
+ *
+ * Since: 1.1.1
+ */
+#ifdef CUT_DISABLE_SOCKET_SUPPORT
+#define cut_assert_equal_sockaddr(expected, actual, ...)  \
+    cut_notify("don't define CUT_DISABLE_SOCKET_SUPPORT " \
+               "to use cut_assert_equal_sockaddr().")
+#else
+#define cut_assert_equal_sockaddr(expected, actual, ...) do             \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_equal_sockaddr_helper(expected, actual,          \
+                                             #expected, #actual),       \
+            __VA_ARGS__),                                               \
+        cut_assert_equal_sockaddr(expected, actual, __VA_ARGS__));      \
+} while (0)
+#endif
+
 /**
  * cut_error:
  * @format: the message format. See the printf() documentation.
