@@ -23,12 +23,6 @@
 
 #include <string.h>
 
-#include <glib/gstdio.h>
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#else
-#  include <io.h>
-#endif
 #include <errno.h>
 
 #include <cutter.h>
@@ -38,11 +32,15 @@
 #include <cutter/cut-test-runner.h>
 #include "../lib/cuttest-assertions.h"
 
+#include <glib/gstdio.h>
+
 #ifndef CUT_DISABLE_SOCKET_SUPPORT
-#  ifdef HAVE_WINSOCK2_H
+#  ifdef G_OS_WIN32
 #    include <winsock2.h>
 #    include <ws2tcpip.h>
+#    include <io.h>
 #  else
+#    include <unistd.h>
 #    include <sys/socket.h>
 #    include <netinet/in.h>
 #    include <arpa/inet.h>
@@ -53,7 +51,7 @@ void test_equal_boolean(void);
 void test_not_equal_boolean(void);
 void test_equal_int(void);
 void test_not_equal_int(void);
-#ifdef HAVE_STDINT_H
+#ifdef CUT_HAVE_STDINT_H
 void test_equal_int_least8(void);
 void test_not_equal_int_least8(void);
 void test_equal_int_least16(void);
@@ -77,7 +75,7 @@ void test_not_equal_intmax(void);
 #endif
 void test_equal_uint(void);
 void test_not_equal_uint(void);
-#ifdef HAVE_STDINT_H
+#ifdef CUT_HAVE_STDINT_H
 void test_equal_uint_least8(void);
 void test_not_equal_uint_least8(void);
 void test_equal_uint_least16(void);
@@ -101,6 +99,8 @@ void test_not_equal_uintmax(void);
 #endif
 void test_equal_size(void);
 void test_not_equal_size(void);
+void test_equal_char(void);
+void test_not_equal_char(void);
 void test_equal_string(void);
 void test_equal_string_with_diff(void);
 void test_equal_string_with_folded_diff(void);
@@ -315,7 +315,7 @@ test_not_equal_int (void)
                            NULL);
 }
 
-#ifdef HAVE_STDINT_H
+#ifdef CUT_HAVE_STDINT_H
 static void
 stub_equal_int_least8 (void)
 {
@@ -799,7 +799,7 @@ test_not_equal_uint (void)
                            NULL);
 }
 
-#ifdef HAVE_STDINT_H
+#ifdef CUT_HAVE_STDINT_H
 static void
 stub_equal_uint_least8 (void)
 {
@@ -1283,6 +1283,48 @@ test_not_equal_size (void)
                            NULL);
 }
 
+static void
+stub_equal_char (void)
+{
+    cut_assert_equal_char('a', 'a');
+    MARK_FAIL(cut_assert_equal_char('a', 'b'));
+}
+
+void
+test_equal_char (void)
+{
+    test = cut_test_new("assert-equal-char", stub_equal_char);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "assert-equal-char", NULL,
+                           "<'a' == 'b'>",
+                           "'a'", "'b'",
+                           FAIL_LOCATION, "stub_equal_char",
+                           NULL);
+}
+
+static void
+stub_not_equal_char (void)
+{
+    cut_assert_not_equal_char('a', 'b');
+    MARK_FAIL(cut_assert_not_equal_char('a', 'a'));
+}
+
+void
+test_not_equal_char (void)
+{
+    test = cut_test_new("assert-not-equal-char", stub_not_equal_char);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "assert-not-equal-char", NULL,
+                           "<'a' != 'a'>",
+                           "'a'", "'a'",
+                           FAIL_LOCATION, "stub_not_equal_char",
+                           NULL);
+}
+
 static void
 stub_equal_string (void)
 {
